@@ -1262,6 +1262,10 @@ extern char *var_smtpd_sasl_realm;
 #define DEF_SMTPD_SASL_EXCEPTIONS_NETWORKS	""
 extern char *var_smtpd_sasl_exceptions_networks;
 
+#define VAR_SMTPD_SASL_TYPE	"smtpd_sasl_type"
+#define DEF_SMTPD_SASL_TYPE	"cyrus"
+extern char *var_smtpd_sasl_type;
+
 #define VAR_SMTPD_SND_AUTH_MAPS	"smtpd_sender_login_maps"
 #define DEF_SMTPD_SND_AUTH_MAPS	""
 extern char *var_smtpd_snd_auth_maps;
@@ -2141,10 +2145,14 @@ extern char *var_flush_service;
  /*
   * Session cache service.
   */
-#define VAR_SCACHE_SERVICE		"connection_cache_service"
+#define VAR_SCACHE_SERVICE		"connection_cache_service_name"
 #define DEF_SCACHE_SERVICE		"scache"
 extern char *var_scache_service;
 
+#define VAR_SCACHE_PROTO_TMOUT		"connection_cache_protocol_timeout"
+#define DEF_SCACHE_PROTO_TMOUT		"5s"
+extern int var_scache_proto_tmout;
+
 #define VAR_SCACHE_TTL_LIM		"connection_cache_ttl_limit"
 #define DEF_SCACHE_TTL_LIM		"2s"
 extern int var_scache_ttl_lim;
@@ -2395,7 +2403,7 @@ extern int var_anvil_stat_time;
 #if 0
 #include <anvil_clnt.h>
 
-#define VAR_ANVIL_SERVICE		"client_connection_rate_service"
+#define VAR_ANVIL_SERVICE		"client_connection_rate_service_name"
 #define DEF_ANVIL_SERVICE		"local:" ANVIL_CLASS "/" ANVIL_SERVICE
 extern char *var_anvil_service;
 
