@@ -11,22 +11,23 @@
 /*	\fBpostconf\fR [\fB-ev\fR] [\fB-c \fIconfig_dir\fR]
 /*	[\fIparameter=value ...\fR]
 /*
-/*	\fBpostconf\fR [\fB-bv\fR] [\fB-c \fIconfig_dir\fR] [\fItemplate_file\fR]
+/*	\fBpostconf\fR [\fB-btv\fR] [\fB-c \fIconfig_dir\fR] [\fItemplate_file\fR]
 /* DESCRIPTION
-/*	The \fBpostconf\fR(1) command prints the actual value of
-/*	\fIparameter\fR (all known parameters by default) one
-/*	parameter per line, changes its value, or prints other
-/*	information about the Postfix mail system.
+/*	The \fBpostconf\fR(1) command displays the actual values
+/*	of configuration parameters, changes configuration parameter
+/*	values, or displays other configuration information about
+/*	the Postfix mail system.
 /*
 /*	Options:
 /* .IP "\fB-b\fR [\fItemplate_file\fR]"
 /*	Display the message text that appears at the beginning of
-/*	delivery status notification (DSN) messages of undeliverable
-/*	mail, for delayed mail, for successful delivery, or for
-/*	mail delivery verification.  You can override the built-in
-/*	message text by specifying one template file at the end of
-/*	the postconf(1) command line, or by specifying a template
-/*	file in main.cf with the bounce_template_file parameter.
+/*	delivery status notification (DSN) messages, with $\fBname\fR
+/*	expressions replaced by actual values.  To override the
+/*	built-in message text, specify a template file at the end
+/*	of the command line, or specify a template file in main.cf
+/*	with the \fBbounce_template_file\fR parameter.
+/*	To force selection of the built-in message text templates,
+/*	specify an empty template file name (in shell language: "").
 /*
 /*	This feature is available with Postfix 2.3 and later.
 /* .IP "\fB-c \fIconfig_dir\fR"
@@ -129,11 +130,21 @@
 /*	The result is a group file entry in \fBgroup\fR(5) format.
 /* .RE
 /* .RE
-/* .sp
+/* .IP
 /*	Other table types may exist depending on how Postfix was built.
 /* .IP \fB-n\fR
 /*	Print parameter settings that are not left at their built-in
 /*	default value, because they are explicitly specified in main.cf.
+/* .IP "\fB-t\fR [\fItemplate_file\fR]"
+/*	Display the templates for delivery status notification (DSN)
+/*	messages. To override the built-in templates, specify a
+/*	template file at the end of the command line, or specify a
+/*	template file in main.cf with the \fBbounce_template_file\fR
+/*	parameter.  To force selection of the built-in templates,
+/*	specify an empty template file name (in shell language:
+/*	"").
+/*
+/*	This feature is available with Postfix 2.3 and later.
 /* .IP \fB-v\fR
 /*	Enable verbose logging for debugging purposes. Multiple \fB-v\fR
 /*	options make the software increasingly verbose.
@@ -160,6 +171,7 @@
 /* FILES
 /*	/etc/postfix/main.cf, Postfix configuration parameters
 /* SEE ALSO
+/*	bounce(5), bounce template file format
 /*	postconf(5), configuration parameters
 /* README FILES
 /* .ad
@@ -941,13 +953,13 @@ int     main(int argc, char **argv)
     /*
      * Parse JCL.
      */
-    while ((ch = GETOPT(argc, argv, "bc:deEhmlnv")) > 0) {
+    while ((ch = GETOPT(argc, argv, "bc:deEhmlntv")) > 0) {
 	switch (ch) {
 	case 'b':
 	    if (ext_argv)
-		msg_fatal("option -b cannot be specified multiple times");
+		msg_fatal("specify one of -b and -t");
 	    ext_argv = argv_alloc(2);
-	    argv_add(ext_argv, "bounce", "-Snexpand_templates", (char *) 0);
+	    argv_add(ext_argv, "bounce", "-SVnexpand_templates", (char *) 0);
 	    break;
 	case 'c':
 	    if (setenv(CONF_ENV_PATH, optarg, 1) < 0)
@@ -983,6 +995,12 @@ int     main(int argc, char **argv)
 	case 'n':
 	    mode |= SHOW_NONDEF;
 	    break;
+	case 't':
+	    if (ext_argv)
+		msg_fatal("specify one of -b and -t");
+	    ext_argv = argv_alloc(2);
+	    argv_add(ext_argv, "bounce", "-SVndump_templates", (char *) 0);
+	    break;
 	case 'v':
 	    msg_verbose++;
 	    break;
@@ -1001,20 +1019,24 @@ int     main(int argc, char **argv)
 	msg_fatal("specify one of -b, -d, -e, -m, -l and -n");
 
     /*
-     * If expanding bounce template message text, show the expansion and
-     * exit.
+     * Display bounce template information and exit.
      */
     if (ext_argv) {
 	if (argv[optind]) {
 	    if (argv[optind + 1])
-		msg_fatal("option -b requires at most one template file");
+		msg_fatal("options -b and -t require at most one template file");
 	    argv_add(ext_argv, "-o",
 		     concatenate(VAR_BOUNCE_TMPL, "=",
 				 argv[optind], (char *) 0),
 		     (char *) 0);
 	}
+	/* Grr... */
+	argv_add(ext_argv, "-o",
+		 concatenate(VAR_QUEUE_DIR, "=", ".", (char *) 0),
+		 (char *) 0);
 	mail_conf_read();
 	mail_run_replace(var_daemon_dir, ext_argv->argv);
+	/* NOTREACHED */
     }
 
     /*
