@@ -39,16 +39,19 @@
 /* .ad
 /* .fi
 /*	SMTP destinations have the following form:
-/* .IP "\fIdomainname\fR, \fIdomainname\fR:\fIport\fR"
-/*	Look up the mail exchangers for the specified domain.
-/* .IP "[\fIhostname\fR], [\fIhostname\fR]:\fIport\fR"
-/*	Look up the address of the specified host.
-/* .IP "[\fIaddress\fR], [\fIaddress\fR]:\fIport\fR"
-/*	Connect to the host at the specified address. An IPv6
-/*	address must be formatted as [\fBipv6\fR:\fIaddress\fR].
-/* .PP
-/*	In all the above cases, when no port is specified, look up
-/*	the port defined as \fBsmtp\fR in \fBservices\fR(4).
+/* .IP \fIdomainname\fR
+/* .IP \fIdomainname\fR:\fIport\fR
+/*	Look up the mail exchangers for the specified domain, and
+/*	connect to the specified port (default: \fBsmtp\fR).
+/* .IP [\fIhostname\fR]
+/* .IP [\fIhostname\fR]:\fIport\fR
+/*	Look up the address(es) of the specified host, and connect to
+/*	the specified port (default: \fBsmtp\fR).
+/* .IP [\fIaddress\fR]
+/* .IP [\fIaddress\fR]:\fIport\fR
+/*	Connect to the host at the specified address, and connect
+/*	to the specified port (default: \fBsmtp\fR). An IPv6 address
+/*	must be formatted as [\fBipv6\fR:\fIaddress\fR].
 /* LMTP DESTINATION SYNTAX
 /* .ad
 /* .fi
@@ -57,13 +60,16 @@
 /*      Connect to the local UNIX-domain server that is bound to the specified
 /*      \fIpathname\fR. If the process runs chrooted, an absolute pathname
 /*      is interpreted relative to the Postfix queue directory.
-/* .IP "\fBinet\fR:\fIhostname\fR, \fBinet\fB:\fIhostname\fR:\fIport\fR"
-/* .IP "\fBinet\fR:[\fIaddress\fR], \fBinet\fR:[\fIaddress\fR]:\fIport\fR"
+/* .IP \fBinet\fR:\fIhostname\fR
+/* .IP \fBinet\fB:\fIhostname\fR:\fIport\fR
+/* .IP \fBinet\fR:[\fIaddress\fR]
+/* .IP \fBinet\fR:[\fIaddress\fR]:\fIport\fR
 /*      Connect to the specified TCP port on the specified local or
 /*      remote host. If no port is specified, connect to the port defined as
 /*      \fBlmtp\fR in \fBservices\fR(4).
 /*      If no such service is found, the \fBlmtp_tcp_port\fR configuration
 /*      parameter (default value of 24) will be used.
+/*	An IPv6 address must be formatted as [\fBipv6\fR:\fIaddress\fR].
 /* .PP
 /* SECURITY
 /* .ad
@@ -341,6 +347,11 @@
 /* .IP "\fBsmtp_connection_cache_time_limit (2s)\fR"
 /*	When SMTP connection caching is enabled, the amount of time that
 /*	an unused SMTP client socket is kept open before it is closed.
+/* .PP
+/*	Available in Postfix version 2.3 and later:
+/* .IP "\fBconnection_cache_protocol_timeout (5s)\fR"
+/*	Time limit for connection cache connect, send or receive
+/*	operations.
 /* TROUBLE SHOOTING CONTROLS
 /* .ad
 /* .fi
@@ -374,9 +385,6 @@
 /*	sub-second delay values.
 /* .IP "\fBdisable_dns_lookups (no)\fR"
 /*	Disable DNS lookups in the Postfix SMTP and LMTP clients.
-/* .IP "\fBsmtp_fallback_relay ($fallback_relay)\fR"
-/*	Optional list of relay hosts for SMTP destinations that can't be
-/*	found or that are unreachable.
 /* .IP "\fBinet_interfaces (all)\fR"
 /*	The network interface addresses that this mail system receives
 /*	mail on.
@@ -421,6 +429,16 @@
 /* .IP "\fBsyslog_name (postfix)\fR"
 /*	The mail system name that is prepended to the process name in syslog
 /*	records, so that "smtpd" becomes, for example, "postfix/smtpd".
+/* .PP
+/*	Available with Postfix 2.2 and earlier:
+/* .IP "\fBfallback_relay (empty)\fR"
+/*	Optional list of relay hosts for SMTP destinations that can't be
+/*	found or that are unreachable.
+/* .PP
+/*	Available with Postfix 2.3 and later:
+/* .IP "\fBsmtp_fallback_relay ($fallback_relay)\fR"
+/*	Optional list of relay hosts for SMTP destinations that can't be
+/*	found or that are unreachable.
 /* SEE ALSO
 /*	qmgr(8), queue manager
 /*	bounce(8), delivery status reports
@@ -577,6 +595,7 @@ char   *var_smtp_generic_maps;
 char   *var_prop_extension;
 bool    var_smtp_sender_auth;
 char   *var_lmtp_tcp_port;
+int     var_scache_proto_tmout;
 
  /*
   * Global variables. smtp_errno is set by the address lookup routines and by
@@ -704,6 +723,7 @@ static void post_init(char *unused_name, char **unused_argv)
 	smtp_scache = scache_multi_create();
 #else
 	smtp_scache = scache_clnt_create(var_scache_service,
+					 var_scache_proto_tmout,
 					 var_ipc_idle_limit,
 					 var_ipc_ttl_limit);
 #endif
